@@ -8,10 +8,10 @@ use crate::api::ApiClient::ApiClient;
 use crate::api::Util::date_deserializer;
 use serde_json::Value;
 use crate::api::DestinyAPI::URL_BASE;
-use crate::api::user::BungieUser::BnetMembership;
+use crate::api::user::BungieUser::{BnetMembership, DestinyProfile};
 use crate::BungieUser;
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, Serialize, Clone)]
 pub struct Clan {
     pub detail: ClanDetail,
 
@@ -19,9 +19,47 @@ pub struct Clan {
     pub allianceStatus: i32,
     pub groupJoinInviteCount: i32,
     pub currentUserMembershipsInactiveForDestiny: bool,
+    pub founder: ClanMember,
 }
 
-#[derive(Deserialize, Serialize)]
+impl Clan {
+    pub async fn get_by_id(apiClient: ApiClient, id: i32) -> Result<Self> {
+        let clan = apiClient.get(format!("{base}/GroupV2/{groupId}/", base = DestinyAPI::URL_BASE, groupId = id)).await?;
+
+        Ok(Clan::from_string_response(clan)?)
+    }
+
+    pub async fn get_by_name(apiClient: ApiClient, name: &str) -> Result<Self> {
+        let clan = apiClient.get(format!("{base}/GroupV2/Name/{groupName}/{groupType}/", base = DestinyAPI::URL_BASE, groupName = name, groupType = 1)).await?;
+
+        Ok(Clan::from_string_response(clan)?)
+    }
+
+    fn from_string_response(response: String) -> Result<Self> {
+        let val: Value = serde_json::from_str(response.as_str())?;
+
+        Ok(serde_json::from_value::<Clan>(val["Response"].clone())?)
+    }
+
+    pub async fn get_members(&self, client: &ApiClient) -> Result<Vec<ClanMember>> {
+        let mut list = vec![];
+
+        let url = format!("{}/GroupV2/{groupId}/Members/", URL_BASE, groupId = self.detail.id);
+        let resp = client.get(url).await?;
+        let val = serde_json::from_str::<Value>(resp.as_str())?;
+        list = serde_json::from_value::<Vec<ClanMember>>(val["Response"]["results"].clone())?;
+
+        Ok(list)
+    }
+
+    pub async fn get_weekly_rewards(&self, client: &ApiClient) -> Result<WeeklyRewardResponse> {
+        let resp = client.get_parse::<WeeklyRewardResponse>(format!("{}/Destiny2/Clan/{groupId}/WeeklyRewardState/", URL_BASE, groupId = self.detail.id), true).await?;
+
+        Ok(resp)
+    }
+}
+
+#[derive(Deserialize, Serialize, Clone)]
 pub struct ClanDetail {
     #[serde(rename = "groupId")]
     pub id: String,
@@ -58,40 +96,10 @@ pub struct ClanDetail {
     #[serde(with = "date_deserializer")]
     pub banExpireDate: Option<NaiveDateTime>,
     pub features: ClanFeatures,
+    pub clanInfo: ClanInfo,
 }
 
-impl Clan {
-    pub async fn get_by_id(apiClient: ApiClient, id: i32) -> Result<Self> {
-        let clan = apiClient.get(format!("{base}/GroupV2/{groupId}/", base = DestinyAPI::URL_BASE, groupId = id)).await?;
-
-        Ok(Clan::from_string_response(clan)?)
-    }
-
-    pub async fn get_by_name(apiClient: ApiClient, name: &str) -> Result<Self> {
-        let clan = apiClient.get(format!("{base}/GroupV2/Name/{groupName}/{groupType}/", base = DestinyAPI::URL_BASE, groupName = name, groupType = 1)).await?;
-
-        Ok(Clan::from_string_response(clan)?)
-    }
-
-    fn from_string_response(response: String) -> Result<Self> {
-        let val: Value = serde_json::from_str(response.as_str())?;
-
-        Ok(serde_json::from_value::<Clan>(val["Response"].clone())?)
-    }
-
-    pub async fn get_members(&self, client: ApiClient) -> Result<Vec<ClanMember>> {
-        let mut list = vec![];
-
-        let url = format!("{}/GroupV2/{groupId}/Members/", URL_BASE, groupId = self.detail.id);
-        let resp = client.get(url).await?;
-        let val = serde_json::from_str::<Value>(resp.as_str())?;
-        list = serde_json::from_value::<Vec<ClanMember>>(val["Response"]["results"].clone())?;
-
-        Ok(list)
-    }
-}
-
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, Serialize, Clone)]
 pub struct ClanFeatures {
     pub maximumMembers: i32,
     pub maximumMembershipsOfGroupType: i32,
@@ -104,32 +112,41 @@ pub struct ClanFeatures {
     pub joinLevel: i32,
 }
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, Serialize, Clone)]
+pub struct ClanInfo {
+    pub clanCallsign: String,
+}
+
+#[derive(Deserialize, Serialize, Clone)]
 pub struct ClanMember {
     pub memberType: i16,
-    pub isOnline: bool,
+    pub isOnline: Option<bool>,
     /// The epoch date indicating when the user last went online/offline (need to implement custom deserializer)
     pub lastOnlineStatusChange: String,
     pub groupId: String,
-    pub destinyUserInfo: DestinyUserInfo,
+    pub destinyUserInfo: DestinyProfile,
     pub bungieNetUserInfo: BnetMembership,
     #[serde(with = "date_deserializer")]
     pub joinDate: Option<NaiveDateTime>,
 }
 
-#[derive(Deserialize, Serialize)]
-pub struct DestinyUserInfo {
-    pub LastSeenDisplayName: String,
-    pub LastSeenDisplayNameType: i16,
-    pub iconPath: String,
-    pub crossSaveOverride: i16,
-    pub applicableMembershipTypes: Vec<i16>,
-    pub isPublic: bool,
-    pub membershipType: i16,
-    pub membershipId: String,
-    pub displayName: String,
-    pub bungieGlobalDisplayName: String,
-    pub bungieGlobalDisplayNameCode: Option<i32>,
+#[derive(Deserialize, Serialize, Clone)]
+pub struct WeeklyRewardResponse {
+    pub milestoneHash: i64,
+    pub rewards: Vec<Rewards>,
+}
+
+#[derive(Deserialize, Serialize, Clone)]
+pub struct Rewards {
+    pub rewardCategoryHash: i64,
+    pub entries: Vec<WeeklyReward>,
+}
+
+#[derive(Deserialize, Serialize, Clone)]
+pub struct WeeklyReward {
+    pub rewardEntryHash: i64,
+    pub earned: bool,
+    pub redeemed: bool,
 }
 
 /*
